@@ -1,12 +1,18 @@
+use std::borrow::Borrow;
 use crate::math::{C, R, N};
 
-pub trait Applicable {
-    fn apply(&self, _: Vec<C>) -> Vec<C>;
+pub trait Applicable: Sized {
+    fn apply(&self, psi: Vec<C>) -> Vec<C>;
+
+    fn act_on(&self) -> N;
+
+    fn dgr(self) -> Self;
+
+    fn c(self, c_mask: N) -> Option<Self>;
 
-    //#[cfg(any(test,doc))]
     fn matrix(&self, size: N) -> Vec<Vec<C>> {
-        const Z: C = C{ re: 0.0, im: 0.0 };
-        const O: C = C{ re: 1.0, im: 0.0 };
+        const O: C = C{ re: 0.0, im: 0.0 };
+        const I: C = C{ re: 1.0, im: 0.0 };
 
         let size = 1 << size;
 
@@ -15,8 +21,8 @@ pub trait Applicable {
 
         for idx in 0..size {
             let mut psi = vec![];
-            psi.resize(size, Z);
-            psi[idx] = O;
+            psi.resize(size, O);
+            psi[idx] = I;
 
             matrix.push(self.apply(psi));
         }
