@@ -1,17 +1,8 @@
 use super::*;
 
-const SQRT_1_2: R = crate::math::SQRT_2 * 0.5;
+const SQRT_1_2: R = crate::math::FRAC_1_SQRT_2;
 
-pub (crate) struct Op {
-    a_mask: N,
-}
-
-impl Op {
-    #[inline(always)]
-    pub fn new(a_mask: N) -> Self {
-        Self{ a_mask }
-    }
-}
+op_impl!{s a_mask}
 
 impl AtomicOp for Op {
     fn atomic_op(&self, psi: &[C], idx: N) -> C {
@@ -38,9 +29,9 @@ impl AtomicOp for Op {
 fn tests() {
     use crate::operator::single::*;
 
-    const SQRT_1_2: C = C{ re: crate::math::SQRT_2 * 0.5, im: 0.0 };
+    const SQRT_1_2: C = C { re: crate::math::FRAC_1_SQRT_2, im: 0.0 };
 
-    let op = SingleOp::from_atomic(Op::new(0b1)).unwrap();
+    let op: SingleOp = Op::new(0b1).into();
     assert_eq!(op.name(), "H1");
     assert_eq!(op.matrix(1),
                [   [SQRT_1_2, SQRT_1_2],
