@@ -1,17 +1,6 @@
 use super::*;
-use crate::math::rotate;
 
-pub (crate) struct Op {
-    ab_mask: N,
-    dagger: bool
-}
-
-impl Op {
-    #[inline(always)]
-    pub fn new(ab_mask: N) -> Self {
-        Self{ ab_mask, dagger: false }
-    }
-}
+op_impl!{d ab_mask}
 
 impl AtomicOp for Op {
     fn atomic_op(&self, psi: &[C], idx: N) -> C {
@@ -48,7 +37,8 @@ fn tests() {
     const I: C = C{ re: 1.0, im: 0.0 };
     const i: C = C{ re: 0.0, im: 1.0 };
 
-    let op = SingleOp::from_atomic(Op::new(0b11)).unwrap().dgr();
+    let op: SingleOp = Op::new(0b11).into();
+    let op = op.dgr();
     assert_eq!(op.name(), "iSWAP3");
     assert_eq!(op.matrix(2),
                [   [I,  O,  O,  O],
