@@ -1,6 +1,7 @@
-use super::*;
 use std::collections::BTreeMap;
 
+use super::*;
+
 pub struct Op {
     phases: BTreeMap<N, C>,
 }
@@ -12,7 +13,7 @@ impl Op {
             let mut jdx = 1;
             while jdx <= *idx {
                 if jdx & *idx != 0 {
-                    phases.entry(jdx).or_insert(C::new(0.0, 0.0)).im += *val;
+                    phases.entry(jdx).or_insert(crate::math::C_ZERO).im += *val;
                 }
                 jdx <<= 1;
             }
@@ -22,6 +23,13 @@ impl Op {
     }
 }
 
+impl Into<SingleOp> for Op {
+    fn into(self) -> SingleOp {
+        let act = self.phases.iter().fold(0, |act, (i, _)| act | *i);
+        SingleOp { act, ctrl: 0, func: Ptr::new(self) }
+    }
+}
+
 impl AtomicOp for Op {
     fn atomic_op(&self, psi: &[C], idx: N) -> C {
         let mut psi = psi[idx];
