@@ -1,10 +1,6 @@
 use super::*;
 
-pub (crate) struct Op {
-    a_mask: N,
-}
-
-simple_op_impl!{a_mask}
+op_impl!{s a_mask}
 
 impl AtomicOp for Op {
     fn atomic_op(&self, psi: &[C], idx: N) -> C {
@@ -31,7 +27,7 @@ fn tests() {
     const O: C = C{ re: 0.0, im: 0.0 };
     const I: C = C{ re: 1.0, im: 0.0 };
 
-    let op = SingleOp::from_atomic(Op::new(0b1)).unwrap();
+    let op: SingleOp = Op::new(0b1).into();
     assert_eq!(op.name(), "Z1");
     assert_eq!(op.matrix(1),
                [   [I, O],
