@@ -1,5 +1,7 @@
 pub (crate) mod virtl;
 pub (crate) mod quant;
+pub (crate) mod class;
 
 pub use virtl::Reg as VReg;
-pub use quant::Reg as QReg;
\ No newline at end of file
+pub use quant::Reg as QReg;
+pub use class::Reg as CReg;
\ No newline at end of file
